=================================================
bioodo - odo parsers for bioinformatics
=================================================

.. image:: https://img.shields.io/pypi/v/bioodo.svg
	   :target: https://pypi.python.org/pypi/bioodo

.. image:: https://img.shields.io/travis/percyfal/bioodo.svg
           :target: https://travis-ci.org/percyfal/bioodo

.. image:: https://anaconda.org/percyfal/bioodo/badges/version.svg
	   :target: https://anaconda.org/percyfal/bioodo

.. image:: https://pyup.io/repos/github/percyfal/bioodo/shield.svg
	   :target: https://pyup.io/repos/github/percyfal/bioodo/
	   :alt: Updates

		 
* Free software: GPL v3
* Documentation: https://percyfal.github.io/bioodo

  
About
---------

`odo <https://github.com/blaze/odo>`_ extensions for bioinformatics.

See `the documentation <http://percyfal.github.io/bioodo/index.html>`_
for more information.

Installation
----------------

Install using the `conda package manager <http://conda.pydata.org/docs/>`_:

.. code-block:: console

   $ conda install -c percyfal bioodo

Alternatively, install directly from PyPi:

.. code-block:: console

   $ pip3 install bioodo
